<?xml version="1.0"?> 

<!-- This stylesheet is used to create the ibm-ejb-jar-bnd.xmi
     file from the ejb-jar.xml file.
  -->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:lxslt="http://xml.apache.org/xslt"
  xmlns:ux="com.unify.nxj.jasxform.WebSphereXalanExtension"
  extension-element-prefixes="ux"
  exclude-result-prefixes="ux"
  version="1.0">

<xsl:output
  method="xml"
  encoding="UTF-8"
  indent="yes"
/>

<lxslt:component prefix="ux"
    functions="getEjbJndiName getJndiNameForEjbRef getJndiNameForResourceRef">
  <lxslt:script lang="javaclass"
    src="com.unify.nxj.jasxform.WebSphereXalanExtension"/>
</lxslt:component>

<xsl:param name="options" />

<xsl:template match="/">
  <ejbbnd:EJBJarBinding
        xmi:version="2.0"
        xmlns:xmi="http://www.omg.org/XMI"
        xmlns:ejbbnd="ejbbnd.xmi"
        xmlns:common="common.xmi"
        xmlns:ejb="ejb.xmi">
    <xsl:attribute name='id' namespace="http://www.omg.org/XMI">
      <xsl:value-of select="concat(ejb-jar/@id, '_Bnd')"/>
    </xsl:attribute>
    <ejbJar>
      <xsl:attribute name='href'>
        <xsl:value-of select="concat('META-INF/ejb-jar.xml#', ejb-jar/@id)"/>
      </xsl:attribute>
    </ejbJar>

    <xsl:apply-templates select="*"/>

  </ejbbnd:EJBJarBinding>
</xsl:template>

<xsl:template match="text()">
</xsl:template>

<xsl:template match="enterprise-beans/*">
  <ejbBindings>
    <xsl:attribute name='id' namespace="http://www.omg.org/XMI">
      <xsl:value-of select="concat(@id, '_Bnd')"/>
    </xsl:attribute>
    <xsl:choose>
      <xsl:when test="local-name()='message-driven'">
        <xsl:attribute name='type' namespace="http://www.omg.org/XMI">ejbbnd:MessageDrivenBeanBinding</xsl:attribute>
        <xsl:attribute name='listenerInputPortName'>
          <!-- Message beans are currently only supported in the
               control center; this attribute will be specified at
               deploy time (see jaslayer/websphere/ibm-ejb-jar-bnd.xsl)
            -->
          <xsl:value-of select="to/be/specified"/>
        </xsl:attribute>
      </xsl:when>
      <xsl:otherwise>
        <xsl:attribute name='jndiName'>
          <xsl:value-of select="ux:getEjbJndiName($options, ejb-name/text())"/>
        </xsl:attribute>
      </xsl:otherwise>
    </xsl:choose>
    <enterpriseBean>
      <xsl:attribute name='href'>
        <xsl:value-of select="concat('META-INF/ejb-jar.xml#', @id)"/>
      </xsl:attribute>
      <xsl:choose>
        <xsl:when test="local-name()='entity'">
          <xsl:attribute name='type' namespace="http://www.omg.org/XMI">ejb:Entity</xsl:attribute>
        </xsl:when>
        <xsl:when test="local-name()='session'">
          <xsl:attribute name='type' namespace="http://www.omg.org/XMI">ejb:Session</xsl:attribute>
        </xsl:when>
        <xsl:when test="local-name()='message-driven'">
          <xsl:attribute name='type' namespace="http://www.omg.org/XMI">ejb:MessageDriven</xsl:attribute>
        </xsl:when>
      </xsl:choose>
    </enterpriseBean>
    <xsl:apply-templates select="ejb-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="ejb-local-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="resource-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="resource-env-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
  </ejbBindings>
</xsl:template>

<xsl:template match="ejb-ref" mode="enterprise-beans">
  <xsl:param name="currentEjbName" select="''"/>
  <ejbRefBindings>
    <xsl:attribute name='id' namespace="http://www.omg.org/XMI">
      <xsl:value-of select="concat(@id, '_Bnd')"/>
    </xsl:attribute>
    <xsl:attribute name='jndiName'>
      <xsl:value-of select=
        "ux:getJndiNameForEjbRef($options, $currentEjbName, ejb-ref-name/text())"/>
    </xsl:attribute>
    <bindingEjbRef>
      <xsl:attribute name='href'>
        <xsl:value-of select="concat('META-INF/ejb-jar.xml#', @id)"/>
      </xsl:attribute>
    </bindingEjbRef>
  </ejbRefBindings>
</xsl:template>

<xsl:template match="ejb-local-ref" mode="enterprise-beans">
  <xsl:param name="currentEjbName" select="''"/>
  <ejbRefBindings>
    <xsl:attribute name='id' namespace="http://www.omg.org/XMI">
      <xsl:value-of select="concat(@id, '_Bnd')"/>
    </xsl:attribute>
    <xsl:attribute name='jndiName'>
      <xsl:value-of select=
        "ux:getJndiNameForEjbLocalRef($options, $currentEjbName, ejb-ref-name/text())"/>
    </xsl:attribute>
    <bindingEjbRef>
      <xsl:attribute name='type' namespace="http://www.omg.org/XMI">common:EJBLocalRef</xsl:attribute>
      <xsl:attribute name='href'>
        <xsl:value-of select="concat('META-INF/ejb-jar.xml#', @id)"/>
      </xsl:attribute>
    </bindingEjbRef>
  </ejbRefBindings>
</xsl:template>

<xsl:template match="resource-ref" mode="enterprise-beans">
  <xsl:param name="currentEjbName" select="''"/>
  <resRefBindings>
    <xsl:attribute name='id' namespace="http://www.omg.org/XMI">
      <xsl:value-of select="concat(@id, '_Bnd')"/>
    </xsl:attribute>
    <xsl:attribute name='jndiName'>
      <xsl:value-of select=
        "ux:getJndiNameForResourceRef($options, $currentEjbName, res-ref-name/text())"/>
    </xsl:attribute>
    <bindingResourceRef>
      <xsl:attribute name='href'>
        <xsl:value-of select="concat('META-INF/ejb-jar.xml#', @id)"/>
      </xsl:attribute>
    </bindingResourceRef>
  </resRefBindings>
</xsl:template>

<xsl:template match="resource-env-ref" mode="enterprise-beans">
  <xsl:param name="currentEjbName" select="''"/>
  <resourceEnvRefBindings>
    <xsl:attribute name='id' namespace="http://www.omg.org/XMI">
      <xsl:value-of select="concat(@id, '_Bnd')"/>
    </xsl:attribute>
    <xsl:attribute name='jndiName'>
      <xsl:value-of select=
        "ux:getJndiNameForResourceEnvRef($options, $currentEjbName, resource-env-ref-name/text())"/>
    </xsl:attribute>
    <bindingResourceEnvRef>
      <xsl:attribute name='href'>
        <xsl:value-of select="concat('META-INF/ejb-jar.xml#', @id)"/>
      </xsl:attribute>
    </bindingResourceEnvRef>
  </resourceEnvRefBindings>
</xsl:template>

</xsl:stylesheet>
