<?xml version="1.0"?> 

<!-- This stylesheet is used to generate a jboss.xml file from
     a ejb-jar.xml file and data provided from the XalanExtension.
  -->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:lxslt="http://xml.apache.org/xslt"
  xmlns:ux="com.unify.nxj.jasxform.JBossXalanExtension"
  extension-element-prefixes="ux"
  exclude-result-prefixes="ux"
  version="1.0">

<xsl:output
  method="xml"
  indent="yes"
/>

<lxslt:component prefix="ux"
    functions="getEjbJndiName getJndiNameForEjbRef getJndiNameForResourceRef">
  <lxslt:script lang="javaclass"
    src="com.unify.nxj.jasxform.JBossXalanExtension"/>
</lxslt:component>

<xsl:param name="doc-type" />
<xsl:param name="options" />

<xsl:template match="/">
  <xsl:value-of select="$doc-type" disable-output-escaping="yes" />
  <jboss>
    <unauthenticated-principal>anonymous</unauthenticated-principal>
    <xsl:apply-templates select="*"/>
  </jboss>
</xsl:template>

<xsl:template match="text()">
</xsl:template>

<xsl:template match="text()" mode="enterprise-beans">
</xsl:template>

<xsl:template match="enterprise-beans">
  <enterprise-beans>
    <xsl:apply-templates mode="enterprise-beans"/>
  </enterprise-beans>
</xsl:template>

<xsl:template match="session|entity" mode="enterprise-beans">
  <xsl:element name="{local-name()}">
    <ejb-name>
      <xsl:value-of select="ejb-name/text()"/>
    </ejb-name>

    <xsl:if test="remote">
      <jndi-name>
        <xsl:value-of select="ux:getEjbJndiName($options, ejb-name/text())"/>
      </jndi-name>
    </xsl:if>

    <xsl:if test="local">
      <local-jndi-name>
        <xsl:value-of select="ux:getEjbLocalJndiName($options, ejb-name/text())"/>
      </local-jndi-name>
    </xsl:if>

    <xsl:if test="session-type/text() = 'Stateful'">
      <configuration-name>Unify NXJ Stateful SessionBean</configuration-name>
    </xsl:if>

    <xsl:apply-templates select="ejb-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="ejb-local-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="resource-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="resource-env-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
  </xsl:element>
</xsl:template>

<xsl:template match="message-driven" mode="enterprise-beans">
  <xsl:element name="{local-name()}">
    <ejb-name>
      <xsl:value-of select="ejb-name/text()"/>
    </ejb-name>
    <configuration-name>Standard Message Driven Bean</configuration-name>
    <destination-jndi-name>queue/BPMEvents</destination-jndi-name>

    <xsl:apply-templates select="ejb-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="ejb-local-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="resource-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="resource-env-ref" mode="enterprise-beans">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
  </xsl:element>
</xsl:template>

<xsl:template match="resource-ref" mode="enterprise-beans">
  <xsl:param name="currentEjbName" select="''"/>
  <resource-ref>
    <res-ref-name><xsl:value-of select="res-ref-name/text()"/></res-ref-name>
    <jndi-name>
      <xsl:value-of select=
          "ux:getJndiNameForResourceRef($options, $currentEjbName, res-ref-name/text())"/>
    </jndi-name>
  </resource-ref>
</xsl:template>

<xsl:template match="resource-env-ref" mode="enterprise-beans">
  <xsl:param name="currentEjbName" select="''"/>
  <resource-env-ref>
    <resource-env-ref-name><xsl:value-of select="resource-env-ref-name/text()"/></resource-env-ref-name>
    <jndi-name>
      <xsl:value-of select=
          "ux:getJndiNameForResourceEnvRef($options, $currentEjbName, resource-env-ref-name/text())"/>
    </jndi-name>
  </resource-env-ref>
</xsl:template>

<xsl:template match="ejb-ref" mode="enterprise-beans">
  <xsl:param name="currentEjbName" select="''"/>
  <ejb-ref>
    <ejb-ref-name><xsl:value-of select="ejb-ref-name/text()"/></ejb-ref-name>
    <jndi-name>
      <xsl:value-of select=
          "ux:getJndiNameForEjbRef($options, $currentEjbName, ejb-ref-name/text())"/>
    </jndi-name>
  </ejb-ref>
</xsl:template>

<xsl:template match="ejb-local-ref" mode="enterprise-beans">
  <xsl:param name="currentEjbName" select="''"/>
  <ejb-local-ref>
    <ejb-ref-name><xsl:value-of select="ejb-ref-name/text()"/></ejb-ref-name>
    <local-jndi-name>
      <xsl:value-of select=
          "ux:getJndiNameForEjbLocalRef($options, $currentEjbName, ejb-ref-name/text())"/>
    </local-jndi-name>
  </ejb-local-ref>
</xsl:template>

</xsl:stylesheet>
