<?xml version="1.0"?> 

<!-- This stylesheet is used to generate a oracle-ejb-jar.xml file from
     a ejb-jar.xml file and some deploy-options.
  -->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:lxslt="http://xml.apache.org/xslt"
  xmlns:ux="com.unify.nxj.jasxform.OracleXalanExtension"
  extension-element-prefixes="ux"
  exclude-result-prefixes="ux"
  version="1.0">

<xsl:output
  method="xml"
  indent="yes"
/>

<lxslt:component prefix="ux"
    functions="getEnvEntry getEjbJndiName getJndiNameForResourceRef">
  <lxslt:script lang="javaclass"
    src="com.unify.nxj.jasxform.OracleXalanExtension"/>
</lxslt:component>

<xsl:param name="options" />
<xsl:param name="doc-type" />

<xsl:template match="/">
  <xsl:value-of select="$doc-type" disable-output-escaping="yes" />
  <orion-ejb-jar>
  <xsl:apply-templates select="*"/>
  </orion-ejb-jar>
</xsl:template>

<xsl:template match="text()">
</xsl:template>

<xsl:template match="enterprise-beans">
  <enterprise-beans>
    <xsl:apply-templates select="session" mode="enterprise-beans"/>
    <xsl:apply-templates select="message-driven" mode="enterprise-beans"/>
  </enterprise-beans>
</xsl:template>


<xsl:template match="session" mode="enterprise-beans">
  <session-deployment 
        name="{ejb-name}"
        location="{ux:getEjbJndiName($options, ejb-name/text())}"
        local-location="{ux:getEjbLocalJndiName($options, ejb-name/text())}">
    <xsl:if test="ejb-name/text() = 'nxjFieldManager'">
        <xsl:attribute name="idletime">never</xsl:attribute>
    </xsl:if>
    <xsl:if test="ejb-name/text() = 'SecurityEJB'">
        <xsl:attribute name="pool-cache-timeout">never</xsl:attribute>
    </xsl:if>
    <xsl:apply-templates select="env-entry">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="ejb-ref">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="ejb-local-ref">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="resource-ref">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="resource-env-ref">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>

  </session-deployment>
</xsl:template>

<xsl:template match="message-driven" mode="enterprise-beans">
  <message-driven-deployment 
        name="{ejb-name}" 
        destination-location="queue/BPMEvents"
        subscription-name="BPM">

    <xsl:apply-templates select="env-entry">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="ejb-ref">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="ejb-local-ref">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="resource-ref">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="resource-env-ref">
      <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
    </xsl:apply-templates>

  </message-driven-deployment>
</xsl:template>

<xsl:template match="env-entry">
  <xsl:param name="currentEjbName" select="''"/>
    <env-entry-mapping name="{env-entry-name}">
	<xsl:value-of select="env-entry-value/text()"/>
    </env-entry-mapping>
</xsl:template>

<xsl:template match="ejb-ref">
  <xsl:param name="currentEjbName" select="''"/>
  <xsl:if test="ancestor::enterprise-beans">
    <ejb-ref-mapping 
	name="{ejb-ref-name}" 
        location="{ux:getJndiNameForEjbRef($options, $currentEjbName, ejb-ref-name/text())}"/>
  </xsl:if>
</xsl:template>

<xsl:template match="ejb-local-ref">
  <xsl:param name="currentEjbName" select="''"/>
  <xsl:if test="ancestor::enterprise-beans">
    <ejb-ref-mapping 
	name="{ejb-ref-name}" 
        location="{ux:getJndiNameForEjbLocalRef($options, $currentEjbName, ejb-link/text())}"/>
  </xsl:if>
</xsl:template>

<xsl:template match="resource-ref">
  <xsl:param name="currentEjbName" select="''"/>
  <xsl:if test="ancestor::enterprise-beans">
    <resource-ref-mapping 
	name="{res-ref-name}" 
	location="{ux:getJndiNameForResourceRef($options, $currentEjbName, res-ref-name/text())}"/>
  </xsl:if>
</xsl:template>

<xsl:template match="resource-env-ref">
  <xsl:param name="currentEjbName" select="''"/>
  <xsl:if test="ancestor::enterprise-beans">
    <resource-env-ref-mapping 
	name="{resource-env-ref-name}" 
	location="{ux:getJndiNameForResourceEnvRef($options, $currentEjbName, resource-env-ref-name/text())}"/>
  </xsl:if>
</xsl:template>

<xsl:template match="assembly-descriptor">
    <xsl:if test="count(security-role) > 0">
        <xsl:apply-templates select="security-role"/>
    </xsl:if>
</xsl:template>

<!--
<xsl:template match="security-role">
  <security-role-assignment>
    <role-name>
      <xsl:value-of select="role-name/text()"/>
    </role-name>
    <xsl:value-of
        select="ux:getEjbPrincipalsForRole($options, role-name/text())"
        disable-output-escaping="yes" />
  </security-role-assignment>
</xsl:template>
-->

</xsl:stylesheet>
