<?xml version="1.0"?> 

<!-- This stylesheet is used to generate a weblogic-ejb-jar.xml file from
     a ejb-jar.xml file and data provided from the XalanExtension.
  -->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:lxslt="http://xml.apache.org/xslt"
  xmlns:ux="com.unify.nxj.jasxform.WebLogicXalanExtension"
  extension-element-prefixes="ux"
  exclude-result-prefixes="ux lxslt"
  version="1.0">

<xsl:output
  method="xml"
  encoding="UTF-8"
  indent="yes"
/>

<lxslt:component prefix="ux"
    functions="getEjbJndiName">
  <lxslt:script lang="javaclass"
    src="com.unify.nxj.jasxform.WebLogicXalanExtension"/>
</lxslt:component>

<xsl:param name="doc-type" />
<xsl:param name="options" />



<xsl:template match="/">
  <xsl:value-of select="$doc-type" disable-output-escaping="yes" />
  <weblogic-ejb-jar>
  <xsl:apply-templates select="*"/>
  </weblogic-ejb-jar>
</xsl:template>

<xsl:template match="text()">
</xsl:template>


<xsl:template match="enterprise-beans/*">
  <weblogic-enterprise-bean>
    <ejb-name>
      <xsl:value-of select="ejb-name/text()"/>
    </ejb-name>

    <xsl:if test="self::message-driven">
      <message-driven-descriptor>
        <destination-jndi-name>queue/BPMEvents</destination-jndi-name>
      </message-driven-descriptor>
    </xsl:if>

    <xsl:if test="(count(resource-ref)+count(resource-env-ref)+count(ejb-ref)+count(ejb-local-ref)) > 0">
      <reference-descriptor>
        <xsl:apply-templates select="resource-ref">
          <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
        </xsl:apply-templates>
        <xsl:apply-templates select="resource-env-ref">
          <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
        </xsl:apply-templates>
        <xsl:apply-templates select="ejb-ref">
          <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
        </xsl:apply-templates>
        <xsl:apply-templates select="ejb-local-ref">
          <xsl:with-param name="currentEjbName" select="ejb-name/text()"/>
        </xsl:apply-templates>
      </reference-descriptor>
    </xsl:if>

    <xsl:if test="remote">
      <jndi-name>
        <xsl:value-of select="ux:getEjbJndiName($options, ejb-name/text())"/>
      </jndi-name>
    </xsl:if>

    <xsl:if test="local">
      <local-jndi-name>
        <xsl:value-of select="ux:getEjbLocalJndiName($options, ejb-name/text())"/>
      </local-jndi-name>
    </xsl:if>

  </weblogic-enterprise-bean>
</xsl:template>

<xsl:template match="resource-ref">
  <xsl:param name="currentEjbName" select="''"/>
  <xsl:if test="ancestor::enterprise-beans">
    <resource-description>
      <res-ref-name>
        <xsl:value-of select="res-ref-name/text()"/>
      </res-ref-name>
      <jndi-name>
        <xsl:value-of select=
            "ux:getJndiNameForResourceRef($options, $currentEjbName, res-ref-name/text())"/>
      </jndi-name>
    </resource-description>
  </xsl:if>
</xsl:template>

<xsl:template match="resource-env-ref">
  <xsl:param name="currentEjbName" select="''"/>
  <xsl:if test="ancestor::enterprise-beans">
    <resource-env-description>
      <res-env-ref-name>
        <xsl:value-of select="resource-env-ref-name/text()"/>
      </res-env-ref-name>
      <jndi-name>
        <xsl:value-of select=
          "ux:getJndiNameForResourceEnvRef($options, $currentEjbName, resource-env-ref-name/text())"/>
      </jndi-name>
    </resource-env-description>
  </xsl:if>
</xsl:template>

<xsl:template match="ejb-ref">
  <xsl:param name="currentEjbName" select="''"/>
  <xsl:if test="ancestor::enterprise-beans">
    <ejb-reference-description>
      <ejb-ref-name>
        <xsl:value-of select="ejb-ref-name/text()"/>
      </ejb-ref-name>
      <jndi-name>
        <xsl:value-of select=
            "ux:getJndiNameForEjbRef($options, $currentEjbName, ejb-ref-name/text())"/>
      </jndi-name>
    </ejb-reference-description>
  </xsl:if>
</xsl:template>

<xsl:template match="ejb-local-ref">
  <xsl:param name="currentEjbName" select="''"/>
  <xsl:if test="ancestor::enterprise-beans">
    <ejb-local-reference-description>
      <ejb-ref-name>
        <xsl:value-of select="ejb-ref-name/text()"/>
      </ejb-ref-name>
      <jndi-name>
        <xsl:value-of select=
            "ux:getJndiNameForEjbLocalRef($options, $currentEjbName, ejb-ref-name/text())"/>
      </jndi-name>
    </ejb-local-reference-description>
  </xsl:if>
</xsl:template>

<xsl:template match="assembly-descriptor">
    <xsl:if test="count(security-role) > 0 and ux:isCC($options)">
        <xsl:apply-templates select="security-role"/>
    </xsl:if>
</xsl:template>

<xsl:template match="security-role">
  <security-role-assignment>
    <role-name>
      <xsl:value-of select="role-name/text()"/>
    </role-name>

    <principal-name>UnifyDummyPrincipal</principal-name>
  </security-role-assignment>
</xsl:template>


</xsl:stylesheet>
