<?xml version="1.0"?> 

<!-- This stylesheet is used to generate a weblogic.xml file from
     a web.xml file and data provided from the XalanExtension.
  -->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:lxslt="http://xml.apache.org/xslt"
  xmlns:ux="com.unify.nxj.jasxform.WebLogicXalanExtension"
  extension-element-prefixes="ux"
  exclude-result-prefixes="ux"
  version="1.0">

<xsl:output
  method="xml"
  encoding="UTF-8"
  indent="yes"
/>

<lxslt:component prefix="ux"
    functions="getJndiNameForEjbRef getJndiNameForResourceRef isCC">
  <lxslt:script lang="javaclass"
    src="com.unify.nxj.jasxform.WebLogicXalanExtension"/>
</lxslt:component>

<xsl:param name="doc-type" />
<xsl:param name="options" />


<xsl:template match="/">
  <xsl:value-of select="$doc-type" disable-output-escaping="yes" />
  <xsl:apply-templates select="*"/>
</xsl:template>

<xsl:template match="web-app">
  <weblogic-web-app>
    <xsl:if test="count(security-role) > 0 and ux:isCC($options)">
        <xsl:apply-templates select="security-role" mode="security-role"/>
    </xsl:if>

    <reference-descriptor>
      <xsl:apply-templates select="*"/>
    </reference-descriptor>

    <session-descriptor>
      <session-param>
        <param-name>CookieName</param-name>
        <param-value>JSESSIONID</param-value>
      </session-param>
      <session-param>
        <param-name>URLRewritingEnabled</param-name>
        <param-value>false</param-value>
      </session-param>
    </session-descriptor>

  </weblogic-web-app>
</xsl:template>

<xsl:template match="text()">
</xsl:template>

<xsl:template match="resource-ref">
  <resource-description>
    <res-ref-name>
      <xsl:value-of select="res-ref-name/text()"/>
    </res-ref-name>
    <jndi-name>
      <xsl:value-of select=
          "ux:getJndiNameForResourceRef($options, '', res-ref-name/text())"/>
    </jndi-name>
  </resource-description>
</xsl:template>

<xsl:template match="ejb-ref">
  <ejb-reference-description>
    <ejb-ref-name>
      <xsl:value-of select="ejb-ref-name/text()"/>
    </ejb-ref-name>
    <jndi-name>
      <xsl:value-of select=
        "ux:getJndiNameForEjbRef($options, '', ejb-ref-name/text())"/>
    </jndi-name>
  </ejb-reference-description>
</xsl:template>

<xsl:template match="security-role" mode="security-role">
  <security-role-assignment>
    <role-name>
      <xsl:value-of select="role-name/text()"/>
    </role-name>

    <principal-name>UnifyDummyPrincipal</principal-name>
  </security-role-assignment>
</xsl:template>

</xsl:stylesheet>
